
To use `semver`, there should be a definition of braking interface change (to release `X+1.Y.Z`).

For `argrelay`, there are multiple interfaces:
*   user interface (expected behaviour)
*   internal plugin interfaces
*   config schema
*   client-server REST interface


See also [version format][version_format.md].

[version_format.md]: version_format.md
